##  Overview
With SAP’s move to the cloud, organizations now need to plan and manage their target architecture in a hybrid environment. This modeling guideline shows how to do that in the most efficient way. It provides best practices for modeling SAP cloud solutions such as SAP S/4HANA, Ariba, SuccessFactors, as well as SAP BTP, and the "old world" with SAP ERP 6.0. It focuses on applications, related business capabilities, and technical elements (IT components, tech category), as well as platforms.
For enterprise architects navigating this landscape, modeling SAP cloud solutions presents specific challenges due to the complexity and depth of the SAP landscape, involving a multitude of modules, components, and dependencies. Enterprise architects must navigate this complexity to create accurate and meaningful models. Moreover, the transition from SAP ERP 6.0 to S/4HANA involves significant architectural changes. It is crucial for enterprise architects to model the current state and the to-be architecture in an accurate and efficient way to support a smooth transformation in time and budget.
